==> mozc_2.19.2623.102+dfsg.orig.tar.xz: mozc-2.19.2623.102+dfsg/src/win32/tip/tip_ui_renderer_immersive.h <==
// Copyright 2010-2016, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_WIN32_TIP_TIP_UI_RENDERER_IMMERSIVE_H_
#define MOZC_WIN32_TIP_TIP_UI_RENDERER_IMMERSIVE_H_

#include <Windows.h>

#include "base/port.h"

namespace mozc {
namespace commands {
class Candidates;
}  // namespace commands

namespace renderer {
class TableLayout;

namespace win32 {
class TextRenderer;
}  // namespace win32

}  // namespace renderer

namespace win32 {
namespace tsf {

// A stateless utility to render candidate UI for immersive mode applications.
class TipUiRendererImmersive {
 public:
  // Returns bitmap handle where candidate UI image is rendered.
  // Caller will have the ownership of the returned object.
  // |size| contains the bitmap size and |left_align_offset| contains the
  // offset length from the left edge with which the candidate UI should be
  // aligned.
  static HBITMAP Render(const commands::Candidates &candidates,
                        const renderer::win32::TextRenderer *text_renderer,
                        renderer::TableLayout *table_layout,
                        SIZE *size,
                        int *left_align_offset);

 private:
  DISALLOW_IMPLICIT_CONSTRUCTORS(TipUiRendererImmersive);
};

}  // namespace tsf
}  // namespace win32
}  // namespace mozc


#endif  // MOZC_WIN32_TIP_TIP_UI_RENDERER_IMMERSIVE_H_

==> mozc_2.26.4220.100+dfsg.orig.tar.xz: mozc-2.26.4220.100+dfsg/src/win32/tip/tip_ui_renderer_immersive.h <==
// Copyright 2010-2020, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_WIN32_TIP_TIP_UI_RENDERER_IMMERSIVE_H_
#define MOZC_WIN32_TIP_TIP_UI_RENDERER_IMMERSIVE_H_

#include <Windows.h>

#include "base/port.h"

namespace mozc {
namespace commands {
class Candidates;
}  // namespace commands

namespace renderer {
class TableLayout;

namespace win32 {
class TextRenderer;
}  // namespace win32

}  // namespace renderer

namespace win32 {
namespace tsf {

// A stateless utility to render candidate UI for immersive mode applications.
class TipUiRendererImmersive {
 public:
  // Returns bitmap handle where candidate UI image is rendered.
  // Caller will have the ownership of the returned object.
  // |size| contains the bitmap size and |left_align_offset| contains the
  // offset length from the left edge with which the candidate UI should be
  // aligned.
  static HBITMAP Render(const commands::Candidates &candidates,
                        const renderer::win32::TextRenderer *text_renderer,
                        renderer::TableLayout *table_layout, SIZE *size,
                        int *left_align_offset);

 private:
  DISALLOW_IMPLICIT_CONSTRUCTORS(TipUiRendererImmersive);
};

}  // namespace tsf
}  // namespace win32
}  // namespace mozc

#endif  // MOZC_WIN32_TIP_TIP_UI_RENDERER_IMMERSIVE_H_
